@@ -1,13 +1,14 @@
 package Message::Transform;
+{
+  $Message::Transform::VERSION = '1.132260';
+}
 
 use strict;use warnings;
 require Exporter;
-use vars qw($VERSION @ISA @EXPORT_OK);
+use vars qw(@ISA @EXPORT_OK);
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(mtransform);
 
-$VERSION = '0.3';
-
 sub mtransform {
     my ($message, $transform) = @_;
     die 'Message::Transform::mtransform: two HASH references required'
